InnerArc

Struct InnerArc 

pub struct InnerArc<Outer, Inner> {
    outer: Outer,
    elem: *const Inner,
}

Fields

outer: Outerelem: *const Inner

Implementations

Source

impl<Outer, Inner> InnerArc<Outer, Inner>

pub unsafe fn new<Arced, Err>( outer: &Outer, arc: impl FnOnce(&Outer) -> &Arc<Arced>, get: impl FnOnce(&Arced) -> Result<&Inner, Err>, ) -> Result<Self, Err>
where Outer: Clone,

Safety

Is only safe if the inner element is not behind inner mutability, and therefore cannot be moved around.

pub unsafe fn inherit<NewInner, Err>( &self, get: impl FnOnce(&Inner) -> Result<&NewInner, Err>, ) -> Result<InnerArc<Outer, NewInner>, Err>
where Outer: Clone,

Safety
pub unsafe fn new_from_outer<Err>( outer: &Outer, get: impl FnOnce(&Outer) -> Result<&Inner, Err>, ) -> Result<Self, Err>
where Outer: Clone,

Safety

Is only safe if the inner element is not behind inner mutability, and therefore cannot be moved around and the provided reference is actually behind the Arc.

pub unsafe fn new_owned_infallible<'a, Arced>( outer: Outer, arc: impl FnOnce(&Outer) -> &Arc<Arced>, get: impl FnOnce(&Arced) -> &'a Inner, ) -> Self
where Outer: Clone + 'a, Inner: 'a,

Safety

Is only safe if the inner element is not behind inner mutability, and therefore cannot be moved around, and the provided reference is actually behind the Arc.

pub const fn outer(&self) -> &Outer